@@ -450,8 +450,10 @@ class PlotConfig:
             self.panel.gridspec.update(left=left, top=1-top,
                                        right=1-right, bottom=bottom)
         for ax in self.canvas.figure.get_axes():
-            ax.update_params()
-            ax.set_position(ax.figbox)
+            # ax.update_params()
+            figpos = ax.get_subplotspec().get_position(self.canvas.figure)
+            ax.set_position(figpos)
+
         if not delay_draw:
             self.canvas.draw()
         if callable(self.margin_callback):
@@ -842,15 +844,21 @@ class PlotConfig:
                 try:
                     for trace, lines in enumerate(ax.get_lines()):
                         x, y = lines.get_xdata(), lines.get_ydata()
-                        if y_minpos is None:
-                            y_minpos= min(y[np.where(y>0)])
-                        else:
-                            y_minpos= min(y_minpos, min(y[np.where(y>0)]))
-                        if x_minpos is None:
-                            x_minpos= min(x[np.where(x>0)])
-                        else:
-                            x_minpos= min(x_minpos, min(x[np.where(x>0)]))
-                            
+                        try:
+                            if not isinstance(y, np.ndarray):
+                                y = np.array(y)
+                            if not isinstance(x, np.ndarray):
+                                x = np.array(x)
+                            if y_minpos is None:
+                                y_minpos= min(y[np.where(y>0)])
+                            else:
+                                y_minpos= min(y_minpos, min(y[np.where(y>0)]))
+                            if x_minpos is None:
+                                x_minpos= min(x[np.where(x>0)])
+                            else:
+                                x_minpos= min(x_minpos, min(x[np.where(x>0)]))
+                        except:
+                            pass
                         if limits == [None, None, None, None]:
                             limits = [min(x), max(x), min(y), max(y)]
                         else:
@@ -888,10 +896,10 @@ class PlotConfig:
                 limits[3] = limits[3] + yrange * self.viewpad /100.0
                 if self.xscale == 'log':
                     limits[0] = max(x_minpos/2, limits[0])
-                   
+
                 if self.yscale == 'log':
                     limits[2] = max(y_minpos/2, limits[2])
-                   
+
 
             if ax in self.user_limits:
                 for i, val in  enumerate(self.user_limits[ax]):
